@@ -58,31 +58,33 @@ class ConfigImpl
 
 void ConfigImpl::__initOptionalPatterns()
 {
+#define SEP "::"
+#define WORD "[^:]*?"
 	const char* optionalPatterns[] = {
 		// used APT vars
-		"acquire::*::*::proxy",
-		"acquire::*::proxy::*",
-		"acquire::*::proxy",
-		"acquire::*::*::dl-limit",
-		"acquire::*::dl-limit::*",
-		"acquire::*::dl-limit",
-		"acquire::*::*::timeout",
-		"acquire::*::timeout::*",
-		"acquire::*::timeout",
-		"dpkg::tools::options::*",
-		"dpkg::tools::options::*::*",
+		"acquire" SEP WORD SEP WORD SEP "proxy",
+		"acquire" SEP WORD SEP "proxy" SEP WORD,
+		"acquire" SEP WORD SEP "proxy",
+		"acquire" SEP WORD SEP WORD SEP "dl-limit",
+		"acquire" SEP WORD SEP "dl-limit" SEP WORD,
+		"acquire" SEP WORD SEP "dl-limit",
+		"acquire" SEP WORD SEP "timeout",
+		"acquire" SEP WORD SEP "timeout" SEP WORD,
+		"acquire" SEP WORD SEP WORD SEP "timeout",
+		"dpkg::tools::options" SEP WORD,
+		"dpkg::tools::options" SEP WORD SEP WORD,
 
 		// used Cupt vars
-		"cupt::downloader::protocols::*::priority",
-		"cupt::downloader::protocols::*::methods",
-		"cupt::downloader::protocols::*::methods::*::priority",
+		"cupt::downloader::protocols" SEP WORD SEP "priority",
+		"cupt::downloader::protocols" SEP WORD SEP "methods",
+		"cupt::downloader::protocols" SEP WORD SEP "methods" SEP WORD SEP "priority",
 	};
+#undef SEP
+#undef WORD
 
-	const sregex convertRegex = sregex::compile("\\*");
 	for (const auto& pattern: optionalPatterns)
 	{
-		auto currentRegexString = regex_replace(string(pattern), convertRegex, "[^:]*?");
-		__optionalPatterns.emplace_back(sregex::compile(currentRegexString));
+		__optionalPatterns.emplace_back(sregex::compile(pattern));
 	}
 }
 
@@ -131,10 +133,10 @@ void ConfigImpl::initializeVariables()
 		// Cupt vars
 		{ "cupt::cache::limit-releases::by-archive::type", "none" },
 		{ "cupt::cache::limit-releases::by-codename::type", "none" },
-		{ "cupt::cache::pin::addendums::downgrade", "-10000" },
-		{ "cupt::cache::pin::addendums::hold", "1000000" },
-		{ "cupt::cache::pin::addendums::not-automatic", "-4000" },
-		{ "cupt::cache::pin::addendums::but-automatic-upgrades", "4200" },
+		{ "cupt::cache::pin::addendums::downgrade", "-6000" },
+		{ "cupt::cache::pin::addendums::hold", "600000" },
+		{ "cupt::cache::pin::addendums::not-automatic", "-1700" },
+		{ "cupt::cache::pin::addendums::but-automatic-upgrades", "1900" },
 		{ "cupt::cache::release-file-expiration::ignore", "no" },
 		{ "cupt::console::allow-untrusted", "no" },
 		{ "cupt::console::assume-yes", "no" },
@@ -189,24 +191,28 @@ void ConfigImpl::initializeVariables()
 		{ "cupt::resolver::external-command", "" },
 		{ "cupt::resolver::keep-recommends", "yes" },
 		{ "cupt::resolver::keep-suggests", "no" },
-		{ "cupt::resolver::max-solution-count", "8192" },
+		{ "cupt::resolver::max-leaf-count", "-1" },
+		{ "cupt::resolver::max-solution-count", "32000" },
 		{ "cupt::resolver::no-remove", "no" },
 		{ "cupt::resolver::synchronize-by-source-versions", "none" },
 		{ "cupt::resolver::track-reasons", "no" },
 		{ "cupt::resolver::type", "fair" },
-		{ "cupt::resolver::score::new", "-5" },
+		{ "cupt::resolver::score::new", "0" },
 		{ "cupt::resolver::score::removal", "-1800" },
-		{ "cupt::resolver::score::removal-of-autoinstalled", "1200" },
+		{ "cupt::resolver::score::removal-of-autoinstalled", "1500" },
 		{ "cupt::resolver::score::removal-of-essential", "-200000" },
-		{ "cupt::resolver::score::upgrade", "100" },
+		{ "cupt::resolver::score::upgrade", "20" },
 		{ "cupt::resolver::score::downgrade", "-800" },
 		{ "cupt::resolver::score::position-penalty", "-2" },
-		{ "cupt::resolver::score::quality-adjustment", "40" },
+		{ "cupt::resolver::score::quality-adjustment", "0" },
 		{ "cupt::resolver::score::unsatisfied-recommends", "-240" },
 		{ "cupt::resolver::score::unsatisfied-suggests", "-60" },
 		{ "cupt::resolver::score::unsatisfied-try", "-10000" },
 		{ "cupt::resolver::score::unsatisfied-wish", "-500" },
 		{ "cupt::resolver::score::failed-synchronization", "-80" },
+		{ "cupt::resolver::score::version-factor::common", "20" },
+		{ "cupt::resolver::score::version-factor::negative", "50" },
+		{ "cupt::resolver::score::version-factor::priority-downgrade", "2200" },
 		{ "cupt::worker::archives-space-limit", "0" },
 		{ "cupt::worker::defer-triggers", "auto" },
 		{ "cupt::worker::download-only", "no" },
@@ -297,7 +303,7 @@ vector< string > ConfigImpl::getConfigurationFilePaths(Config* config) const
 	for (const auto& ignorePathRegexString: config->getList("dir::ignore-files-silently"))
 	{
 		auto fullString = "^.*" + ignorePathRegexString + ".*$";
-		ignorePathRegexes.emplace_back(stringToRegex(fullString));
+		ignorePathRegexes.emplace_back(stringToRegex<sregex>(fullString));
 	}
 
 	vector< string > result;
@@ -586,10 +592,6 @@ static inline bool isCuptOption(const string& optionName)
 {
 	return isFamilyOption(optionName, "cupt");
 }
-static bool isForeignOption(const string& optionName)
-{
-	return !isCuptOption(optionName) && !isFamilyOption(optionName, "dpkg");
-}
 
 void Config::setScalar(const string& optionName, const string& value)
 {
@@ -599,6 +601,11 @@ void Config::setScalar(const string& optionName, const string& value)
 		*charIt = std::tolower(*charIt);
 	}
 
+	if (!isCuptOption(normalizedOptionName))
+	{
+		__impl->regularVars[optionName /* <-- non-normalized one */] = value;
+	}
+
 	{ // translation to cupt variable names
 		auto it = __impl->regularCompatibilityVars.find(normalizedOptionName);
 		if (it != __impl->regularCompatibilityVars.end())
@@ -610,11 +617,6 @@ void Config::setScalar(const string& optionName, const string& value)
 		}
 	}
 
-	if (isForeignOption(normalizedOptionName))
-	{
-		__impl->regularVars[optionName /* <-- non-normalized one */] = value;
-	}
-
 	if (__impl->regularVars.count(normalizedOptionName) || __impl->isOptionalOption(normalizedOptionName))
 	{
 		__impl->regularVars[normalizedOptionName] = value;
